@@ -9,7 +9,7 @@ from sklearn.metrics import roc_auc_score
 import pdpbox
 import plotly.graph_objects as go
 
-from explainerdashboard.explainers import ClassifierBunch
+from explainerdashboard.explainers import ClassifierExplainer
 from explainerdashboard.datasets import titanic_survive, titanic_names
 
 
@@ -21,10 +21,11 @@ class ClassifierBaseExplainerTests(unittest.TestCase):
         model = RandomForestClassifier(n_estimators=5, max_depth=2)
         model.fit(X_train, y_train)
 
-        self.explainer = ClassifierBunch(
+        self.explainer = ClassifierExplainer(
                             model, X_test, y_test, roc_auc_score, 
                             shap='tree',
                             cats=['Sex', 'Cabin', 'Embarked'],
+                            labels=['Not survived', 'Survived'],
                             idxs=test_names)
 
     def test_explainer_len(self):
